from eng_econ import generate_dcostring


@generate_dcostring("F", "P", "Single payment compound amount")
def single_payment_compound_amount_factor(i, n):
    return (1 + i) ** n


@generate_dcostring("P", "F", "Single payment present worth")
def single_payment_present_worth_factor(i, n):
    return (1 + i) ** (-n)


@generate_dcostring("A", "F", "Uniform series sinking fund")
def uniform_series_sinking_fund_factor(i, n):
    return i / ((1 + i) ** n - 1)


@generate_dcostring("A", "P", "Capital recovery")
def capital_recovery_factor(i, n):
    temporary = (1 + i) ** n
    return i * temporary / (temporary - 1)


@generate_dcostring("F", "A", "Uniform series compound amount")
def uniform_series_compound_amount_factor(i, n):
    return ((1 + i) ** n - 1) / i


@generate_dcostring("P", "A", "Uniform series present worth")
def uniform_series_present_wortht_factor(i, n):
    temporary = (1 + i) ** n
    return (temporary - 1) / (i * temporary)


@generate_dcostring("P", "G", "uniform gradient present worth")
def uniform_gradient_present_worth_factor(i, n):
    temporary = (1 + i) ** n
    return (temporary - 1) / (i ** 2 * temporary) - (n / (i * temporary))


@generate_dcostring("F", "G", "uniform gradient future worth")
def uniform_gradient_future_worth_factor(i, n):
    return ((1 + i) ** n - 1) / (i ** 2) - (n / i)


@generate_dcostring("A", "G", "Uniform gradient uniform series")
def uniform_gradient_uniform_series_factor(i, n):
    return 1 / i - (n / ((1 + i) ** n - 1))



__version__ = "0.1.0"


def generate_dcostring(first_notation, second_notation, name):
    notations = {
        "F": "Future worth, value, or amount",
        "P": "Present worth, value, or amount",
        "A": "Uniform amount per interest period",
        "G": "Uniform gradient amount per interest period",
    }
    docstring = f"""
       Factor applies to {first_notation}/{second_notation} => to {first_notation} ({notations[first_notation]}) given {second_notation} ({notations[second_notation]})

       :param i: Interest rate per interest period

       :param n: Number of compounding periods

       :return: {name} factor
       """

    def dec(obj):
        obj.__doc__ = docstring
        return obj

    return dec



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['eng_econ']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'eng-econ',
    'version': '0.1.3',
    'description': 'This package provides some of the basic functions of engineering economics',
    'long_description': '\n# engineering-economics-basics\n\n## Overview\n\nThis package provides some of the basic functions of engineering economics\n\nYou can find it at: [https://pypi.org/project/eng-econ/](https://pypi.org/project/eng-econ/)\n\n## Install\n\n```\npip install eng_econ\n```\n\n## Usage\n\n```\n# Using uniform_gradient_present_worth_factor as an example\nfrom eng_econ.factors import uniform_gradient_present_worth_factor\nuniform_gradient_present_worth_factor(0.01, 20)\n```\n\n## Documents\n\nSee [https://songyu-wang.github.io/engineering-economics-basics/docs/eng_econ/index.html](https://songyu-wang.github.io/engineering-economics-basics/docs/eng_econ/index.html)\n\n## Test Coverage\n\nsee [https://songyu-wang.github.io/engineering-economics-basics/htmlcov/index.html](https://songyu-wang.github.io/engineering-economics-basics/htmlcov/index.html)\n\n### Reference\n\nNational Council of Examiners for Engineering and Surveying(NCEES). FE Reference Handbook, 9.5 Edition, (ISBN 978-1-932613-67-4).\n',
    'author': 'Songyu-Wang',
    'author_email': 'wangsongyuf@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://songyu-wang.github.io/engineering-economics-basics/',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
